#!/bin/bash

# COPYRIGHT 2003-2010, EMULEX CORPORATION                               
# 3333 Susan St., Costa Mesa, CA 92626                                  
#                                                                         
# All rights reserved.  This computer program and related documentation 
# is protected by copyright  and distributed under licenses restricting 
# its use,  copying,  distribution  and decompilation.    This computer 
# program  and its  documentation  are CONFIDENTIAL  and a TRADE SECRET 
# of EMULEX CORPORATION.   The receipt or  possession of  this  program 
# or its documentation does not  convey rights to reproduce or disclose 
# its  contents,  or to  manufacture, use, or sell anything that it may 
# describe, in whole or in part,  without the specific  written consent 
# of  EMULEX CORPORATION.   Any reproduction  of  this program  without 
# the express  written  consent  of EMULEX  CORPORATION  is a violation 
# of the  copyright laws  and may  subject you to  criminal prosecution.

SUCCESS=0
FAILURE=1
STATUS=$SUCCESS
KITNAME=""
LOGFILE_NAME="utils-install.log"
INSTALL_DIR="usr/sbin/ocmanager"
LOGFILE="/${INSTALL_DIR}/${LOGFILE_NAME}"
# Function:  log_message()
#
# Description:
#   Print the strings passed as parameters to both STDOUT as well as
#   to a log file.
#
# Parameters:
#   A series of strings.
#
# Returns:
#   0 on success.
log_message()
{
    local ECHO_OPTIONS
    LOGDIRECTORY=${LOGFILE%/*}
    if [ ! -d ${LOGDIRECTORY} ] ; then
        mkdir -p ${LOGDIRECTORY}
    fi

    if [ $# -eq 0 ] ; then
        echo "" | tee -a ${LOGFILE}
    elif [ -z "$1" ] ; then
        echo "" | tee -a ${LOGFILE}
    elif [ "$1" = "-init" ] ; then
        echo "$0 - $(date)" >> ${LOGFILE}
    else
        while [ -n "$1" ] ; do
            if [ "${1:0:1}" = "-" ] ; then
                ECHO_OPTIONS="${1}"
            else
                echo ${ECHO_OPTIONS} "$1" | tee -a ${LOGFILE}
            fi
            shift
        done
    fi
    return $SUCCESS
}


# Initialize the log file.
log_message -init

rpm -q --quiet elxocmgui
if [ $? -eq 0 ]; then
    HBAGUIQUERY=`rpm -q elxocmgui`
    KITNAME="Enterprise"
    log_message "Uninstalling elxocmgui: $HBAGUIQUERY"
    rpm -e $HBAGUIQUERY
    GUISTATUS=$?
    if [ "$GUISTATUS" = "0" ];then
        log_message "Uninstalling $HBAGUIQUERY completed successfully"
    else
        log_message "An error occurred while uninstalling $HBAGUIQUERY"
        STATUS=$FAILURE
    fi
    log_message ""
fi

rpm -q --quiet elxocmjvm
if [ $? -eq 0 ]; then
    HBAJVMQUERY=`rpm -q elxocmjvm`
    KITNAME="Enterprise"
    log_message "Uninstalling elxocmjvm: $HBAJVMQUERY"
    rpm -e $HBAJVMQUERY
    JVMSTATUS=$?
    if [ "$JVMSTATUS" = "0" ];then
        log_message "Uninstalling $HBAJVMQUERY completed successfully"
    else
        log_message "An error occurred while uninstalling $HBAJVMQUERY"
        STATUS=$FAILURE
    fi
    log_message ""
fi

rpm -q --quiet elxocmcore
if [ $? -eq 0 ]; then
    if [ -z $KITNAME ]; then
        KITNAME="Core"
    fi
    HBACOREQUERY=`rpm -q elxocmcore`
    log_message "Uninstalling elxocmcore: $HBACOREQUERY"
    rpm -e $HBACOREQUERY
    CORESTATUS=$?
    if [ "$CORESTATUS" = "0" ];then
        log_message "Uninstalling $HBACOREQUERY completed successfully"
    else
        log_message "An error occurred while uninstalling $HBACOREQUERY"
        STATUS=$FAILURE
    fi
    log_message ""
fi

HBAAPI_LIST=`rpm -qa | grep elxocmlibhbaapi`
if [ $? -eq 0 ]; then
    if [ -z $KITNAME ]; then
        KITNAME="Core"
    fi
    for hbaapirpm in $HBAAPI_LIST
    do
        log_message "Uninstalling elxocmlibhbaapi: $hbaapirpm"
        rpm -e $hbaapirpm
        HBAAPISTATUS=$?
        if [ "$HBAAPISTATUS" = "0" ];then
            log_message "Uninstalling $hbaapirpm completed successfully"
        else
            log_message "An error occurred while uninstalling $hbaapirpm"
            STATUS=$FAILURE
        fi
        log_message ""
   done
fi

if [ -n "$KITNAME" ]; then
    if [ $STATUS -eq $FAILURE ]; then
         log_message "An error occurred while uninstalling the OneCommand Manager $KITNAME Kit"
    else
         log_message "OneCommand Manager $KITNAME Kit un-installation completed successfully."
    fi
else
    log_message "OneCommand Manager is not installed."
fi

log_message ""
exit $SUCCESS
